jacinle.io.common
=================

.. automodule:: jacinle.io.common

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      auto_close
      fsize_format
      get_ext
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: auto_close

.. autofunction:: fsize_format

.. autofunction:: get_ext


